@@ -33,12 +33,12 @@
   #:use-module (oop goops)
   #:use-module (gnome gobject)
   #:use-module (gnome gtk)
-  #:use-module (grip do)
-  #:use-module (grip dates)
+  #:use-module (grip iter)
+  #:use-module (grip date)
   #:use-module (grip passwd)
   #:use-module (grip i18n)
-  #:use-module (grip nbs)
-  #:use-module (grip tex-utils)
+  #:use-module (grip number)
+  #:use-module (grip latex)
   #:use-module (grip gnome)
   #:use-module (foliot globals)
   #:use-module (foliot db)
@@ -58,7 +58,7 @@
 
 (eval-when (expand load eval)
   (textdomain "p-draft")
-  (bindtextdomain "p-draft" (storage-get 'pofdir)))
+  (bindtextdomain "p-draft" (ref %foliot-store 'pofdir)))
 
 
 ;;;
@@ -79,7 +79,7 @@
 {extarticle}~%"))
 
 (define (fp/write-draft-inputs ostream)
-  (let ((latexdir (storage-get 'latexdir)))
+  (let ((latexdir (ref %foliot-store 'latexdir)))
     (format ostream "
   \\input{~A/draft-packages}
   \\input{~A/draft-commandes}
@@ -319,7 +319,8 @@
     (dotimes (i (length tuple-group-values))
       (let* ((c-val (list-ref tuple-group-values i))
 	     (same? (cond ((string? c-val) (string=? (vector-ref current i) c-val))
-			  ((number? c-val) (fp/=? (vector-ref current i) c-val))
+			  ((number? c-val) (float=? (vector-ref current i)
+                                                    (* c-val 1.0)))         ;; ensure float
 			  (else
 			   (format #t "Warning: fp/group-compare-current, unmanaged value type ~S~%" c-val)
 			   #t)))) ;; <- not knowing, we suppose it is the same as before
@@ -491,7 +492,8 @@ Core fields: ~S
  Row format: ~S~%~%"
 	  groups core-fields preamble rowfmt))
 
-(define (fp/write-draft-core-content ostream tuples groups core-fields fp-widget tl-widget draftLT-file-object)
+(define (fp/write-draft-core-content ostream tuples groups
+                                     core-fields fp-widget tl-widget draftLT-file-object)
   (let* ((current (make-vector (length groups) #f))
 	 (pdir (p-directory draftLT-file-object))
 	 (ltx-offset (fp/get-core-table-offset groups))
@@ -502,14 +504,17 @@ Core fields: ~S
     (fp/write-ltx-offset ostream ltx-offset)
     (receive (preamble rowfmt nb-cols description?)
 	(fp/get-ltx-preamble-rowfmt-nb-cols core-fields)
-      (if (storage-get 'debug) (fp/display-ltx-preamble-debug-info groups core-fields preamble rowfmt nb-cols description?))
+      (if (ref %foliot-store 'debug)
+          (fp/display-ltx-preamble-debug-info groups core-fields
+                                              preamble rowfmt nb-cols description?))
       (if (null? groups)
 	  (begin
 	    (format ostream "\\bigskip~%")
 	    (fp/write-draft-ltxtable-cmd ostream ltx-shortname)
 	    (tex/write-utf8-comment-line ltx-stream)
 	    (fp/write-draft-begin-ltx ltx-stream preamble)
-	    (fp/write-draft-ltx-tuples ltx-stream tuples core-fields rowfmt nb-cols description? ltx-offset)
+	    (fp/write-draft-ltx-tuples ltx-stream tuples
+                                       core-fields rowfmt nb-cols description? ltx-offset)
 	    (fp/write-draft-end-ltx ltx-stream)
 	    (close ltx-stream))
 	  (begin
